@@ -185,6 +185,77 @@ sub list {
     }
 }
 
+sub gem {
+    my ( $self, @args ) = @_;
+
+    my $dispatch = {
+        reinstall => sub {
+            my $file    = $args[1];
+            my $gemlist = '';
+
+            if ( !defined $file || !-f $file ) {
+                $gemlist = qx[gem list];
+            }
+            else {
+                {
+                    local $/;
+                    open my $fh, '<', $file;
+                    $gemlist = <$fh>;
+                    close $fh;
+                }
+            }
+
+            my $gems = $self->_parse_gemlist($gemlist);
+            $self->_reinstall_gems($gems);
+        },
+    };
+
+    if ( exists $dispatch->{ $args[0] } ) {
+        $dispatch->{ $args[0] }->();
+    }
+
+    return 1;
+}
+
+sub _parse_gemlist {
+    my ( $self, $gemlist ) = @_;
+
+    my $gems = {};
+    for my $line ( split /\n/, $gemlist ) {
+        my ( $gem, $versions ) = $line =~ /
+            ([-_\w]+)\s # capture gem name
+            [(](
+                (?:
+                    (?:
+                        (?:\d+\.)*\d+
+                    )
+                    ,?\s?
+                )+
+            )[)]/mxg;
+        $gems->{$gem} = [ split ', ', $versions ] if defined $gem;
+    }
+
+    return $gems;
+}
+
+sub _reinstall_gems {
+    my ( $self, $gems ) = @_;
+
+    say "Reinstalling all gems:";
+    for my $gem ( keys %$gems ) {
+        for my $version ( @{ $gems->{$gem} } ) {
+            my $cmd = "gem install $gem ";
+            $cmd .= "-v=$version";
+            $cmd .= " --ignore-dependencies";
+
+            say "  Installing $gem version $version";
+            my $output = qx[$cmd];
+        }
+    }
+
+    return 1;
+}
+
 sub _sort_rubies {
     my ( $self, $rubies ) = @_;
 
@@ -198,12 +269,9 @@ sub _sort_rubies {
     }
 
     for my $version ( sort { $a cmp $b } keys %{$major_versions} ) {
-        my @patchlevels
-            = grep { defined $_ && $_ =~ /p\d{1,3}/ } @{ $major_versions->{$version} };
-        my @pre
-            = grep { defined $_ && $_ =~ /preview\d{0,1}|rc\d{0,1}/ } @{ $major_versions->{$version} };
-        my @old
-            = grep { defined $_ && $_ =~ /^\d/ } @{ $major_versions->{$version} };
+        my @patchlevels = grep { defined $_ && $_ =~ /p\d{1,3}/ } @{ $major_versions->{$version} };
+        my @pre         = grep { defined $_ && $_ =~ /preview\d{0,1}|rc\d{0,1}/ } @{ $major_versions->{$version} };
+        my @old         = grep { defined $_ && $_ =~ /^\d/ } @{ $major_versions->{$version} };
 
         my @numeric_levels;
         for my $level (@patchlevels) {
@@ -401,7 +469,7 @@ This is an unstable development release not ready for production!
 
 =head1 VERSION
 
-Version 0.003009
+Version 0.003011
 
 =head1 SYNOPSIS
 
@@ -428,7 +496,7 @@ Name your gemset. More sophisticated support for gemsets needs to be implemented
 =head2 agent_string
 
 The user agent used when downloading ruby.
-Defaults to Ruby::VersionManager/0.003009.
+Defaults to Ruby::VersionManager/0.003011.
 
 =head2 archive_type
 
